@@ -8,6 +8,7 @@ Derv2 <- function(penden.env,lambda0) {
     Derv2.temp[,j] <- get("Derv1.cal",penden.env)%*%get("Derv1.cal",penden.env)[j,]
   }
 
-  penalty <- lambda0*get("Dm",penden.env)
-  return(list(Derv2.pen=(Derv2.temp+penalty),Derv2.cal=(Derv2.temp)))
+  #penalty <- lambda0*get("Dm",penden.env)
+  #return(list(Derv2.pen=(Derv2.temp+penalty),Derv2.cal=(Derv2.temp)))
+  return(list(Derv2.pen=(Derv2.temp+lambda0*get("Dm",penden.env)),Derv2.cal=(Derv2.temp)))
 } 
